extensions [matrix]

breed [bedbugs bedbug]
breed [traps trap]

bedbugs-own
[
  death
  still
  spore
]

traps-own
[
  c
  r
]


patches-own
[
  pheromone
  pc
  pr
  infection
]

globals
[
  pheromone-level
  next-pheromone-level
  Deff
  total-death-time
]

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;


to setup
  clear-all
  resize-world (0 - dim) dim (0 - dim) dim                                                     ;set up the size of the environment (shape should also be changed)
  set pheromone-level matrix:make-constant (dim + dim + 1) (dim + dim + 1) 0                   ;create a matrix of the same dimension than the world called pheromone-level and makes all coeficients equals 0
  set next-pheromone-level matrix:make-constant (dim + dim + 1) (dim + dim + 1) 0              ;same action than the previous one but with a next-pheromone-level matrix
  set-default-shape bedbugs "bug"                                                              ;give to all the bedbugs the "bug" shape
  set-default-shape traps "square"                                                             ;give to all the traps the square shape
  ask patches [set infection 0]                                                                ;set the infection variable value to 0
  ask one-of patches [make-nests]                                                              ;create the nest
  make-furnitures number-furnitures length-furnitures                                          ;ask to run the make-furnitures module with the given parameters
  make-traps number-traps                                                                      ;ask to run the make-traps module with the given parameters
  make-bedbugs number-bedbugs                                                                  ;ask to run the make-bugs module with the given parameters
  let rap ((length-furnitures * length-furnitures) / ((dim + dim + 1) * (dim + dim + 1)))      ;compute the ration between the area of the furnitures and the area of the world
  set Deff ((D / (1 - rap)) * (1 - ((2 * rap) / (1 + rap))))                                   ;compute the effective diffusion coefficient
  ask patches [                                                                                ;for each patch,...
    translate-patch-matrix pxcor pycor                                                         ;tranlate every patch coordinate in the matrix's cases coordinates.return the line's number pr and the colone's number pc for each patch
    set pheromone matrix:get pheromone-level pr pc                                             ;give the value of the square (pr and pc) of the pheromone-level matrix to the pheromone variable of the patch studied
  ]
  reset-ticks                                                                                  ;reset the ticks counter to 0
end



to make-bedbugs [ number ]
  create-bedbugs number [           ;create the given number of bedbugs...
    set color green                 ;set their color to green
    let xc 0                        ;create an xc variable and give it a value of 0
    let yc 0                        ;create an yc variable and give it a value of 0
    ask one-of patches with [pcolor = blue] [   ;select one patches among all the patches with a blue color...
      set xc pxcor                  ;give the value of the x coordinate of the observed patch to the xc variable
      set yc pycor                  ;same but with the variable yc and the y coordinate of the patch
    ]
    set xcor xc + random 3          ;set the x coordinate of the bedbug to a value of the sum of 3 and the variable xc
    set ycor yc + random 3          ;same but with yc and the y coordinate
    set size 3                      ;set their size to 3
    let t random-float 1.1          ;create a t variable and set it to a random number between 0 and 1.1
    while [t <= 0.9] [              ;while the value of t is below or equal to 0.9...
      set t random-float 1.1        ;set the t value to a random number between 0 and 1.1
    ]
    set death death-time * t        ;set the death timer to the input value (death-time)
    set still still-time            ;set the still timer to the input value (still-time)
    set spore 0                     ;set the spore variable value to 0
  ]
end


to make-traps [number]
  create-traps number [                       ;create the traps number...
    set color brown                           ;give them the brown color
    let patch-color 0                         ;set the patch-color value to 0
    setxy int(random-xcor) int(random-ycor)   ;give the trap integer random coordinates
    ask patch-here [                          ;for the patch we're observing...
      set patch-color pcolor                  ;set the patch-color value equals to the pcolor one
    ]
    if patch-color = black [                  ;if the value of patch-color is black ...
      ask patch-here [set pcolor brown]       ;set the color of the patch we're observing to brown
    ]
    while [patch-color != black] [            ;while the patch-color value is black...
      setxy int(random-xcor) int(random-ycor) ;give trap integer random coordinates
      if [pcolor] of patch-here = black [     ;if the color of the patch we're observing is black...
        ask patch-here [set pcolor brown]     ;set the color of the patch we're observing to brown
        set patch-color black                 ;set the patch-color value to black
      ]
    ]                        ;the last lines prevent the program to stack traps and furnitures or nest
    set xcor int(xcor)       ;makes their x coordinates a whole number
    set ycor int(ycor)       ;makes their y coordinates a whole number
    translate-traps-matrix xcor ycor   ;translate the traps coordinates to matrix's coordinates, return r and c
    matrix:set pheromone-level r c 100 ;give the 100 value to every square of the pheromone-level's matrix corresponding to a trap
    matrix:set next-pheromone-level r c 100  ;same as before, but for the next-pheromone-level matrix
  ]
end

to make-furnitures [number leng]
  let n 0                                                                               ;set the n variable value to 0
  let dist 0                                                                            ;set the dist variable value to 0
  ask n-of number-furnitures patches                                                    ;among all patches, ask n of them
  [
    if n > 0 [                                                                          ;if the value of n is superior to 0...
      set dist distance min-one-of patches with [pcolor = white] [distance myself]      ;give to dist the value of the distance between the observed patch and the closest patch with the color white
    ]
    set pcolor white                                                                    ;set the color of the observed patch to white
    if n > 0 [                                                                          ;if the value of n is superior to 0...
      while [dist < length-furnitures + 2] [                                            ;while the dist value is inferior to the length-furniture value + 2 ...
        set pcolor black                                                                ;set the color of the observed patch to black
        ask one-of patches [                                                            ;among all the patches, ask to one...
          set dist distance min-one-of patches with [pcolor = white] [distance myself]  ;give to dist the value of the distance between the observed patch and the closest patch with the color white
          if dist > length-furnitures + 2 [                                             ;if the dist value is superior to length-furnitures + 2...
            set pcolor white                                                            ;set the color of the observed patch to white
          ]
        ]
      ]
    ]
    set n n + 1                                                                         ;set the value of n to n+1
  ] ;this code create the core of the furniture, around wich the furniture will be build. It also create those core with enough distance between them to create the furnitures without stacking them
  ask patches with [pcolor = white] [                                                   ;for each white patch...
    if length-furnitures = 2 [                                                          ;if the value of length-furnitures is equal to 2...
      ask patch-at 1 0 [set pcolor white]                                               ;color the patch on the right side of the observed patch in white
      ask patch-at 0 1 [set pcolor white]                                               ;same that the previous command but for the patch above the observed patch
      ask patch-at 1 1 [set pcolor white]
    ]
    if length-furnitures = 3 [ask neighbors [set pcolor white]]                         ;if length-furnitures is equals to 3, color the eight neighbors of the observed patch in white
    if length-furnitures = 4 [
      ask patch-at 1 0 [set pcolor white]
      ask patch-at 2 0 [set pcolor white]
      ask patch-at 3 0 [set pcolor white]
      ask patch-at 0 1 [set pcolor white]
      ask patch-at 0 2 [set pcolor white]
      ask patch-at 0 3 [set pcolor white]
      ask patch-at 1 1 [set pcolor white]
      ask patch-at 1 2 [set pcolor white]
      ask patch-at 1 3 [set pcolor white]
      ask patch-at 2 1 [set pcolor white]
      ask patch-at 2 2 [set pcolor white]
      ask patch-at 2 3 [set pcolor white]
      ask patch-at 3 1 [set pcolor white]
      ask patch-at 3 2 [set pcolor white]
      ask patch-at 3 3 [set pcolor white]
    ]
    if length-furnitures = 5 [
      ask neighbors [set pcolor white]
      ask neighbors [ask neighbors [set pcolor white]]
    ]
  ];this part of the code create the furnitures form their core and by coloring some of their neighbors
end

to make-nests     ;create the nest
  ask one-of patches [                             ;for one patch among all the others...
    let patch-color-n pcolor                       ;create the variable patch-color-n and give it the value of the color of the observed patch
    if patch-color-n = black [                     ;if the value of patch-color-n is black
      set pcolor blue                              ;set the color of the observed patch to blue
      set infection number-eggs                    ;set the infection variable value to the input value (number-eggs)
      let pxcorn pxcor                             ;create the pxcorn variable and set its value to pxcor
      let pycorn pycor                             ;same with the variable pyxorn and the value of pycor
      ask neighbors [                              ;for each 8 neighbors of the observed patch...
        set pcolor blue                            ;set their color to blue
        set infection number-eggs                  ;set their infection variable value to the input value
        translate-patch-matrix pxcor pycor         ;tranlate every patch coordinate in the matrix's cases coordinates.return the line's number pr and the colone's number pc for each patch
        matrix:set pheromone-level pr pc 100       ;give the 100 value to every square of the pheromone-level's matrix corresponding to a trap
        matrix:set next-pheromone-level pr pc 100  ;same as before, but for the next-pheromone-level matrix
      ]
    ]
  ]
end

to translate-traps-matrix [x y]
  set c x + dim                 ;set the c value to x + dim
  set r y + (dim - (2 * (y)))   ;set the r value to y + (dim - (2 * (y)))
end

to translate-patch-matrix [px py]
  set pc px + dim                  ;set the pc value to px + dim
  set pr py + (dim - (2 * (py)))   ;set the pr value to py + (dim - (2 * (y)))
end

;;;;;;;;;;;;;;;;;;;;;
;;; Go procedures ;;;
;;;;;;;;;;;;;;;;;;;;;

to go
  ask patches [                                                                                                                ;for each patch
    if pcolor != white and pcolor != blue and pcolor != yellow [                                                                 ;if the color of the observed patch is neither blue, yellow nor white ...                                                                                                  ;if the color of the observed patch is not white...
      let cth count turtles-here                                                                                                 ;give to the variable cth the turtle's number in the patch
      let c-ijn matrix:get pheromone-level pr pc                                                                                 ;give to the c-ijn variable the value of the square pr pc from the pheromone-level's matrix
      let c-i+dxjn 0                                                                                                             ;give to the c-i+dxjn variable the 0 value
      let c-i-dxjn 0                                                                                                             ;same action
      let c-ij+dyn 0                                                                                                             ;same action
      let c-ij-dyn 0                                                                                                             ;same action
      ifelse pc = 2 * dim [set c-i+dxjn 0] [set c-i+dxjn matrix:get pheromone-level pr (pc + 1)]                                 ;give to the c-i+dxjn variable the value of the pr pc+1 square from the pheromone-level matrix only if pc is not equals to 32
      ifelse pc = 0 [set c-i-dxjn 0] [set c-i-dxjn matrix:get pheromone-level pr (pc - 1)]                                       ;same, but in the case of pc different of 0
      ifelse pr = 2 * dim [set c-ij+dyn 0] [set c-ij+dyn matrix:get pheromone-level (pr + 1) pc]
      ifelse pr = 0 [set c-ij-dyn 0] [set c-ij-dyn matrix:get pheromone-level (pr - 1) pc]
;   the 4 last lines allow the program to avoid trying taking any value that is not comprise in the matrix dimention
      if cth = 0                                                                                                                 ;if there is no turtles in the patch observed...
      [
        let pl ((Deff * (((c-i+dxjn + c-i-dxjn - (2 * c-ijn)) / 1) + ((c-ij+dyn + c-ij-dyn - (2 * c-ijn)) / 1)) * 1) + c-ijn)    ;compute the pl variable with this formula
        if pl > 100 [set pl 100]                                                                                                 ;if pl is greater than 100, gives it 100 for value
        matrix:set next-pheromone-level pr pc pl                                                                                 ;give to the next-pheromone-level matrix's square corresponding to the observed patch the value pl
        ask patch pxcor pycor [set pheromone matrix:get next-pheromone-level pr pc]                                              ;give the pl value to the pheromone's variable of the observed patch
      ]
    ]
  ]
  set pheromone-level matrix:copy next-pheromone-level                                                                           ;copy the next-pheromone-level matrix in the pheromone-level matrix
  ask patches with [pcolor != white and pcolor != blue and pcolor != yellow] [                                                   ;for each patch with a color that isn't blue, yellow or white...                                                                                         ;for each patch with a different color than white
    set pcolor scale-color red pheromone 0 150                                                                                   ;makes a red color scale depending on the pheromone quantities of each patch
  ]
  ask bedbugs [                                               ;for each bedbugs...
    ifelse [pcolor] of patch-here = blue                      ;if the color of the patch where the observed bedbug is isn't blue ...
    [
      ifelse still > 1                                        ;if the still timer value is above 1...
      [
        set still still - 1                                   ;decrease the still timer value of 1
      ]
      [                                                       ;...else...
        rt 180                                                ;turn the bedbug of 180 degrees to the right
        fd 2                                                  ;move the bedbug from its position to 2 unit of distance in the direction the bedbug was facing
        lt flutter-amount 45                                  ;turn the bedbug to the left by a certain value (calculated by the flutter amount function)
        fd 2
        set still still-time                                  ;set the still timer to the input value
      ]
    ];stop the bedbug on the patch if its color is blue
    [                                                         ;...else...
      move-thru-field                                         ;initiate the move-thru-field function
    ]
    let dist-d distance min-one-of traps [distance myself]    ;create the dist-d variable and give it the value of the distance between the observed bedbug and the closest trap
    if dist-d < 2 and spore = 0 [                             ;if dist-d is lesser than 2 and the spore variable of the observed bedbug has a value of 0...
      ask bedbugs-here [
        set spore 1                                           ;set the spore variable value of the observed bedbug to 1
        set color orange                                      ;set the bedbug's color to orange
      ]
    ]
    if spore = 1 [                                            ;if the spore variable of the observed bedbug is 1...
      ifelse death > 1 [                                      ;if the death timer of the bedbug is above 1...
        set death death - 1                                   ;decrease the death timer value of 1
      ]
      [                                                       ;...else...
        ask patch-here [                                      ;for the patch where the observed bedbug is located...
          ifelse pcolor = blue [                              ;if the color of the patch is blue...
            if infection > 0 [set infection infection - 1]    ;if the infection variable value is above 0, decrease its value by 1
            ask bedbugs-here [die]                            ;ask the bedbug who is on the observed patch to die
          ]
          [                                                   ;...else...
            set pcolor yellow                                 ;set the color of the observed patch to yellow
            ask bedbugs-here [die]                            ;ask the bedbug who is on the observed patch to die
          ]
        ]
      ]; code the death mechanism for the bedbug when a bedbug is close to a trap
    ]
    let cpy count patches with [pcolor = yellow]
    if cpy > 1 [
      let dist-y distance min-one-of patches with [pcolor = yellow] [distance myself]
      if dist-y < 2 and spore = 0 [
        ask bedbugs-here [
          set spore 1
          set color orange
        ]
      ]
      if spore = 1 [
        ifelse death > 1 [
          set death death - 1
        ]
        [
          ask patch-here [
            ifelse pcolor = blue [
              if infection > 0 [set infection infection - 1]
              ask bedbugs-here [die]
            ]
            [
            set pcolor yellow
            ask bedbugs-here [die]
            ]
          ]
        ]
      ]
    ];same as the previous code but set the death mechanism when a bedbug is close to a yellow patch
  ]
  ask patches with [pcolor = blue and infection = 0] [    ;for each patches with a blue color and an infection variable value of 0...
    ask neighbors with [pcolor = blue] [                  ;for each 8 neighbors of the observed patch with a blue color...
      ask neighbors with [pcolor = blue] [                ;for each 8 neighbors of the observed neighbors with a blue color...
        set pcolor black                                  ;set their color to black
        translate-patch-matrix pxcor pycor                ;translate the coordinates of the patch to matrix coordinates
        matrix:set pheromone-level pr pc 0                ;give the 0 value to the square of the pheromone-level's matrix corresponding of the observed patch
        matrix:set next-pheromone-level pr pc 0           ;same but with the next-pheromone-level matrix
      ]
      set pcolor black
      translate-patch-matrix pxcor pycor
      matrix:set pheromone-level pr pc 0
      matrix:set next-pheromone-level pr pc 0
    ]
  ];code the death mechanism for the nest
  let c2 count bedbugs                                    ;count the total number of bedbugs
  if c2 = 0 [                                             ;if there is not any bedbug still alive...
    set total-death-time ticks                            ;give to the variable total-death-time the actual number of ticks
    print word "temps relatif d'élimination total :" total-death-time     ;print the sentence "temps relatif d'élimination total :" followed by the total-death-time variable
    stop                                                  ;stop the program
  ]
  tick
end


;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Runtime Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to move-thru-field    ;; turtle procedure
  ifelse ([pheromone] of patch-here <= 40)
  [
    ;; if there is no detectable pheromones move randomly
    rt flutter-amount 45
  ]
  [
    ifelse (random 25 = 0)
    ;; add some additional randomness to the bugs's movement, this allows some small
    ;; probability that the bug might "escape" from the light.
    [
      rt flutter-amount 60
    ]
    [
      ;; turn toward the more intense trap
      maximize
      ;; if the trap ahead is not above the sensitivity threshold  head towards the light
      ;; otherwise move randomly
      ifelse ( [pheromone] of patch-ahead 1 <= 70 )
      [
        lt ( turn-angle )
      ]
      [
        rt flutter-amount 60
      ]
    ]
  ]
  if not can-move? 1
    [ maximize ]
  ifelse [pcolor] of patch-ahead 1 != white       ;if the color of the patch ahead of 1 unit of distance of the observed bedbug is note white
  [
    fd 1                                          ;move the bedbug of one in the direction the bedbug was facing
  ]
  [                                               ;...else...
    rt 180                                        ;turn the bedbug to the right by 180 degrees
    fd 4                                          ;move the bedbug by 4
  ];prevent the bedbug to enter on the furnitures
  ask patch-here [                                ;for the patch containing the observed bedbug...
    let cth-r count traps-here                    ;create the cth-r variable and give it the value of the number of traps on the observed bedbug
    if cth-r = 1                                  ;if cth-r has a value of 1...
    [
      ask bedbugs-at 0 0 [                        ;ask to the bedbug contained by the observed patch...
        rt flutter-amount 45                      ;turn to the right of the amount of degree calculated by the flutter-amount function
        fd 4                                      ;move the bedbug by 4
      ]
    ]
  ];prevent the bedbug to get stuck on a patch containing a trap
end

to maximize  ;; turtle procedure
  face max-one-of patches in-radius 1 [pheromone]
end


to-report flutter-amount [limit]
  ;; This routine takes a number as an input and returns a random value between
  ;; (+1 * input value) and (-1 * input value).
  ;; It is used to add a random flutter to the bugs's movements
  report random-float (2 * limit) - limit
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
803
604
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-22
22
-22
22
0
0
1
ticks
30.0

SLIDER
18
28
190
61
dim
dim
0
100
22.0
1
1
NIL
HORIZONTAL

SLIDER
19
71
191
104
number-furnitures
number-furnitures
0
10
5.0
1
1
NIL
HORIZONTAL

SLIDER
26
133
198
166
length-furnitures
length-furnitures
0
5
5.0
1
1
NIL
HORIZONTAL

SLIDER
16
191
188
224
number-traps
number-traps
0
100
6.0
1
1
NIL
HORIZONTAL

SLIDER
20
243
192
276
number-bedbugs
number-bedbugs
0
100
9.0
1
1
NIL
HORIZONTAL

SLIDER
21
299
193
332
D
D
0.01
0.24
0.24
0.001
1
NIL
HORIZONTAL

SLIDER
20
352
192
385
turn-angle
turn-angle
45
180
45.0
5
1
NIL
HORIZONTAL

BUTTON
48
415
111
448
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
130
415
193
448
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
20
495
192
528
death-time
death-time
0
100
100.0
1
1
NIL
HORIZONTAL

SLIDER
21
547
193
580
still-time
still-time
0
100
22.0
1
1
NIL
HORIZONTAL

SLIDER
21
598
193
631
number-eggs
number-eggs
0
20
10.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
